## 多核扩展

蝙蝠侠学习了如何利用多核资源来提升应用程序的性能。他使用了以下命令来启动多进程和多线程：

<Row>
  <Col>
  </Col>
  <Col sticky>
    <CodeGroup title="Request">

      ```python {{ title: 'untyped' }}
      python3 app.py --workers=N --process=M
      ```

      ```python {{title: 'typed'}}
      python3 app.py --workers=N --process=M
      ```
    </CodeGroup>

  </Col>
</Row>

---

## 下一步

掌握了多核扩展技术后，蝙蝠侠希望进一步探索 Robyn 框架的高级特性。Robyn 随即向他介绍了一些更为复杂和强大的功能。

- [高级特性](/documentation/zh/api_reference/advanced_features)
